@@ -100,7 +100,7 @@ def bidsify_units(orig_unit):
     return orig_unit
 
 
-def use_heuristic(heur_file, sub, ses, filename, outdir, run='', record_label=''):
+def use_heuristic(heur_file, sub, ses, filename, outdir, take='', record_label=''):
     """
     Import and use the heuristic specified by the user to rename the file.
 
@@ -134,7 +134,7 @@ def use_heuristic(heur_file, sub, ses, filename, outdir, run='', record_label=''
 
     # Initialise a dictionary of bids_keys that has already "recording"
     bids_keys = {'sub': '', 'ses': '', 'task': '', 'acq': '', 'ce': '',
-                 'dir': '', 'rec': '', 'run': run, 'recording': record_label}
+                 'dir': '', 'rec': '', 'run': '', 'recording': record_label}
 
     # Start filling bids_keys dictionary and path with subject and session
     if sub.startswith('sub-'):
@@ -154,7 +154,7 @@ def use_heuristic(heur_file, sub, ses, filename, outdir, run='', record_label=''
 
     # Load heuristic and use it to fill dictionary
     heur = utils.load_heuristic(heur_file)
-    bids_keys.update(heur.heur(Path(filename).stem, run))
+    bids_keys.update(heur.heur(Path(filename).stem, take))
 
     # If bids_keys['task'] is still empty, stop the program
     if not bids_keys['task']:
